@@ -1,6 +1,6 @@
 /*  This file is part of the Kate project.
  *
- *  Copyright (C) 2010 Dominik Haumann <dhaumann kde org>
+ *  Copyright (C) 2010-2018 Dominik Haumann <dhaumann@kde.org>
  *  Copyright (C) 2010 Diana-Victoria Tiriplica <diana.tiriplica@gmail.com>
  *
  *  This library is free software; you can redistribute it and/or
@@ -67,7 +67,7 @@ SwapFile::SwapFile(KTextEditor::DocumentPrivate *document)
     // fixed version of serialisation
     m_stream.setVersion(QDataStream::Qt_4_6);
 
-    // conect the timer
+    // connect the timer
     connect(syncTimer(), SIGNAL(timeout()), this, SLOT(writeFileToDisk()), Qt::DirectConnection);
 
     // connecting the signals
@@ -627,7 +627,7 @@ void SwapFile::writeFileToDisk()
 
 #ifndef Q_OS_WIN
         // ensure that the file is written to disk
-#ifdef HAVE_FDATASYNC
+#if HAVE_FDATASYNC
         fdatasync(m_swapfile.handle());
 #else
         fsync(m_swapfile.handle());
@@ -659,7 +659,7 @@ void SwapFile::showSwapFileMessage()
 
 void SwapFile::showDiff()
 {
-    // the diff creator deletes itself thorugh deleteLater() when it's done
+    // the diff creator deletes itself through deleteLater() when it's done
     SwapDiffCreator *diffCreator = new SwapDiffCreator(this);
     diffCreator->viewDiff();
 }
